@@ -70,6 +70,7 @@ Mixer_ALSA::Mixer_ALSA( Mixer* mixer, int device ) : Mixer_Backend(mixer,  devic
 
 Mixer_ALSA::~Mixer_ALSA()
 {
+	kDebug() << "Destruct " << this;
    close();
 }
 
@@ -478,6 +479,8 @@ void Mixer_ALSA::deinitAlsaPolling()
 int
 Mixer_ALSA::close()
 {
+	kDebug() << "close " << this;
+
   int ret=0;
   m_isOpen = false;
 
@@ -509,11 +512,11 @@ Mixer_ALSA::close()
 
   mixer_elem_list.clear();
   mixer_sid_list.clear();
-  m_mixDevices.clear();
   m_id2numHash.clear();
 
   deinitAlsaPolling();
 
+  closeCommon();
   return ret;
 }
 
