@@ -37,6 +37,12 @@
 #  include <canberra.h>
 #endif
 
+// PA_VOLUME_UI_MAX landed in pulseaudio-0.9.23, so this can be removed when/if
+// minimum requirement is ever bumped up (from 0.9.12 currently)
+#ifndef PA_VOLUME_UI_MAX
+#define PA_VOLUME_UI_MAX (pa_sw_volume_from_dB(+11.0))
+#endif
+
 #define HAVE_SOURCE_OUTPUT_VOLUMES PA_CHECK_VERSION(1,0,0)
 
 #define KMIXPA_PLAYBACK     0
@@ -828,7 +834,6 @@ void Mixer_PULSE::addDevice(devinfo& dev, bool isAppStream)
 {
     if (dev.chanMask != Volume::MNONE) {
         MixSet *ms = 0;
-	bool isCapture = (m_devnum == KMIXPA_CAPTURE || m_devnum == KMIXPA_APP_CAPTURE);
         if (m_devnum == KMIXPA_APP_PLAYBACK && s_mixers.contains(KMIXPA_PLAYBACK))
             ms = s_mixers[KMIXPA_PLAYBACK]->getMixSet();
         else if (m_devnum == KMIXPA_APP_CAPTURE && s_mixers.contains(KMIXPA_CAPTURE))
@@ -842,11 +847,8 @@ void Mixer_PULSE::addDevice(devinfo& dev, bool isAppStream)
         if (isAppStream)
             md->setApplicationStream(true);
 
-	kDebug() << "Adding Pulse volume " << dev.name << ", isCapture= " << isCapture << ", isAppStream= " << isAppStream << "=" << md->isApplicationStream() << ", devnum=" << m_devnum;
-	if ( isCapture )
-	  md->addCaptureVolume(v);
-	else
-	  md->addPlaybackVolume(v);
+        kDebug() << "Adding Pulse volume " << dev.name << ", isCapture= " << (m_devnum == KMIXPA_CAPTURE || m_devnum == KMIXPA_APP_CAPTURE) << ", isAppStream= " << isAppStream << "=" << md->isApplicationStream() << ", devnum=" << m_devnum;
+        md->addPlaybackVolume(v);
         md->setMuted(dev.mute);
         m_mixDevices.append(md->addToPool());
     }
